## soton_corenlp project

soton_corenlppy is a Python NLP library containing a body of open source research code being continually developed at the University of Southampton, UK. its release is intended to support ongoing research and commercial applications involving the University of Southampton.

soton_corenlppy works with Python 3.7 and has been tested on Windows 10 and Ubuntu 18.04 LTS.

Feature suggestions and/or bug reports can be sent to {sem03}@soton.ac.uk. We do not however offer any software support beyond the examples and API documentation already provided.

The software is copyright University of Southampton, UK. It has been supported over a multi-year period by the following grants: EU FP7 TRIDEC (258723), EU FP7 REVEAL (610928), EU H2020 project GRAVITATE (665155), ESRC FloraGuard (ES/R003254/1), DSTL CYShadowWatch (ACC2005442), InnovateUK LPLP (104875), NERC GloSAT (NE/S015604/1). This software can only be used for research, education or evaluation purposes. A free commercial license is available on registration request to {sem03}@soton.ac.uk.


## soton_corenlppy user documentation

https://github.com/stuartemiddleton/soton_corenlppy


## soton_corenlppy license

https://github.com/stuartemiddleton/soton_corenlppy/blob/master/LICENSE.txt


## Python libs needed

Python libs: nltk >= 3.4, psycopg2>=2.8,setuptools >= 46
